@@ -143,40 +143,69 @@ func (r *Retriever) StartTokenRefresh() error {
 	return fmt.Errorf("Unknown error during TokenRefresh")
 }
 
+func clusterNeedsCCX(cluster types.ManagedClusterInfo, clusterCCXMap map[string]bool) bool {
+	lock.Lock()
+	defer lock.Unlock()
+	needsCCX := clusterCCXMap[cluster.ClusterID]
+	return needsCCX
+}
+
 // RetrieveCCXReport ...
 func (r *Retriever) RetrieveCCXReport(
 	hubID string,
 	input chan types.ManagedClusterInfo,
 	output chan types.ProcessorData,
+	clusterCCXMap map[string]bool,
 ) {
 	for {
 		cluster := <-input
 		// If the cluster id is empty do nothing
 		if cluster.Namespace == "" || cluster.ClusterID == "" {
-			return
+			continue
+		}
+
+		if !clusterNeedsCCX(cluster, clusterCCXMap) {
+			output <- types.ProcessorData{
+				ClusterInfo: cluster,
+				Reports:     types.Reports{},
+			}
+			continue
 		}
 
 		glog.Infof("RetrieveCCXReport for cluster %s", cluster.Namespace)
 		req, err := r.CreateInsightsRequest(context.TODO(), r.CCXUrl, cluster, hubID)
 		if err != nil {
-			glog.Warningf("Error creating HttpRequest for cluster %s (%s), %v", cluster.Namespace, cluster.ClusterID, err)
+			handleCCXRequestErr(err, "Error creating HttpRequest for cluster %s (%s), %v", output, cluster)
 			continue
 		}
 		response, err := r.CallInsights(req, cluster)
 		if err != nil {
-			glog.Warningf("Error getting good Response for cluster %s (%s), %v", cluster.Namespace, cluster.ClusterID, err)
+			handleCCXRequestErr(err, "Error getting good Response for cluster %s (%s), %v", output, cluster)
 			continue
 		}
 
 		policyReports, err := r.GetPolicyInfo(response, cluster)
 		if err != nil {
-			glog.Warningf("Error creating PolicyInfo for cluster %s (%s), %v", cluster.Namespace, cluster.ClusterID, err)
+			handleCCXRequestErr(err, "Error creating PolicyInfo for cluster %s (%s), %v", output, cluster)
 			continue
 		}
 		output <- policyReports
 	}
 }
 
+func handleCCXRequestErr(
+	err error,
+	message string,
+	output chan types.ProcessorData,
+	cluster types.ManagedClusterInfo,
+) {
+	glog.Warningf(message, cluster.Namespace, cluster.ClusterID, err)
+	output <- types.ProcessorData{
+		ClusterInfo: cluster,
+		Reports:     types.Reports{},
+	}
+}
+
 // CreateInsightsRequest ...
 func (r *Retriever) CreateInsightsRequest(
 	ctx context.Context,
